<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation>Automatische Übersetzung von &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation>Suche, bitte warten ...</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation>Automatischer Übersetzer (Linguist)</translation>
    </message>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation>
            <numerusform>1 Eintrag wurde automatisch übersetzt</numerusform>
            <numerusform>%n Einträge wurden automatisch übersetzt</numerusform>
        </translation>
    </message>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - Automatische Übersetzung</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation>Übersetzung als erledigt markieren</translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation>Einträge mit bereits existierender Übersetzung neu übersetzen</translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation>Erledigte Einträge übersetzen</translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation>Wörterbücher</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>&amp;Ausführen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation>Geänderte Einträge werden als unerledigt gekennzeichnet, wenn die obige Einstellung &apos;Übersetzung als erledigt markieren&apos; nicht aktiviert ist</translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation>Der automatische Übersetzer wird in der angegebenen Reihenfolge durch die ausgewählten Wörterbücher gehen</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation>Die Übersetzungsdatei &apos;%1&apos; ist leer und wird daher nicht geladen.</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation>&lt;qt&gt;Mehrfach vorhandene Meldungen in &apos;%1&apos;:</translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation>&lt;p&gt;[weitere mehrfach vorhandene Nachrichten weggelassen]</translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation>&lt;p&gt;* ID: %1</translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation>&lt;p&gt;* Kontext: %1&lt;br&gt;* Quelle: %2</translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation>&lt;br&gt;* Kommentar: %3</translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation>Die Regeln zur Pluralbildung der Sprache &apos;%1&apos; sind in Linguist nicht definiert.
Es wird mit einer einfachen Universalform gearbeitet.</translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation>&apos;%2&apos; kann nicht erzeugt werden: %1</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <extracomment>&lt;language&gt; (&lt;territory&gt;)</extracomment>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation>Universalform</translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation: %1</source>
        <translation>Möglicherweise überflüssiger Kurzbefehl im Übersetzungstext: %1</translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation: %1</source>
        <translation>Kurzbefehl fehlt im Übersetzungstext: %1</translation>
    </message>
    <message>
        <source>Translation does not have same leading and trailing whitespace as the source text: %1</source>
        <translation>Die Leerzeichen am Anfang bzw. Ende des Übersetzungstextes stimmen nicht mit denen des Ursprungstextes überein: %1</translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text: %1</source>
        <translation>Interpunktion am Ende des Übersetzungstextes unterscheidet sich von der Interpunktion des Ursprungstextes: %1</translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>Ein Vorschlag aus dem Wörterbuch für &apos;%1&apos; wurde nicht berücksichtigt.</translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text: %1</source>
        <translation>Platzhalter im Übersetzungstext und Ursprungstext unterscheiden sich: %1</translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n/%Ln place marker: %1</source>
        <translation>Der erforderliche Platzhalter (%n/%Ln) fehlt in der Übersetzung: %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Dieses Fenster erlaubt die Suche in der Übersetzungsdatei.</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Geben Sie den Text ein, nach dem gesucht werden soll.</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation>Wenn aktiviert, wird in den Ursprungstexten gesucht.</translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation>Wenn ausgewählt, wird in den Übersetzungen gesucht.</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Wenn aktiviert, werden Texte wie &apos;TeX&apos; und &apos;tex&apos; als unterschiedlich betrachtet.</translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation>Wenn ausgewählt, werden Kommentare und Kontextnamen durchsucht.</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation>&amp;Suchmuster:</translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation>&amp;Ursprungstexte</translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation>&amp;Übersetzungen</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>&amp;Groß-/Kleinschreibung beachten</translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation>&amp;Kommentare</translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation>Tastenkürzel &amp;ignorieren</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Klicken Sie hier, um zum nächsten Vorkommen des Suchtextes zu springen.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Weitersuchen</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicken Sie hier, um das Fenster zu schließen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>Obsoleted messages are skipped when checked.</source>
        <translation>Bewirkt, dass als &apos;obsolet&apos; gekennzeichnete Texte übersprungen werden.</translation>
    </message>
    <message>
        <source>Skip &amp;obsolete</source>
        <translation>&apos;&amp;obsolet&apos; überspringen</translation>
    </message>
    <message>
        <source>Lets you use a Perl-compatible regular expression</source>
        <translation>Ermöglicht die Verwendung eines Perl-kompatiblen regulären Ausdrucks</translation>
    </message>
    <message>
        <source>Regular &amp;expression</source>
        <translation>&amp;Regulärer Ausdruck</translation>
    </message>
    <message>
        <source>T&amp;ranslation status:</source>
        <translation>Ü&amp;bersetzungsstatus:</translation>
    </message>
    <message>
        <source>Lets you filter the search target by translation status</source>
        <translation>Ermöglicht das Eingrenzen der Suche nach Übersetzungsstatus</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Erledigt</translation>
    </message>
    <message>
        <source>Unfinished</source>
        <translation>Unerledigt</translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Delete</translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Shift+Alt+Insert</translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Insert</translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation>Bestätigung - Qt Linguist</translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation>Soll die ausgefüllte Längenvariante gelöscht werden?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation>Hauptfenster</translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation>&amp;Wörterbuch</translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation>Wörterbuch &amp;Schließen</translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation>Wörterbuch &amp;bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation>Wörterbuch &amp;drucken</translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation>V&amp;alidierung</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation>&amp;Ansichten</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>&amp;Werkzeugleisten</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>&amp;Übersetzung</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Ö&amp;ffnen ...</translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Qt-Übersetzungsdatei (TS-Datei) zum Bearbeiten öffnen</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation>Dieses Fenster schließen und das Programm beenden.</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation>Änderungen an der Qt-Übersetzungsdatei speichern</translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation>Zum vorherigen unerledigten Eintrag gehen.</translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation>Zum nächsten unerledigten Eintrag gehen.</translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation>Zum vorigen Eintrag gehen.</translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation>Zum nächsten Eintrag gehen.</translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation>Diesen Eintrag als erledigt markieren und zum nächsten unerledigten Eintrag gehen.</translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation>Ursprungstext übernehmen</translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation>Schr&amp;eibgeschützt öffnen ...</translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation>&amp;Alle speichern</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter...</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Speichern unter ...</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Änderungen an dieser Qt-Übersetzungsdatei in einer neuen Datei speichern.</translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation>&amp;Freigeben</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>Qt-Nachrichtendatei (QM-Datei) aus der aktuellen Übersetzungsdatei erzeugen.</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drucken ...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation>Zu&amp;letzt bearbeitete Dateien</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation>Liste aller Übersetzungseinheiten in der aktuellen Übersetzungsdatei drucken.</translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation>Die letzte Änderung an der Übersetzung rückgängig machen.</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>Die letzte rückgängig gemachte Änderung wieder herstellen.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>Den ausgewählten Übersetzungstext in die Zwischenablage kopieren und löschen.</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>Den ausgewählten Übersetzungstext in die Zwischenablage kopieren.</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Einfügen</translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation>Text aus der Zwischenablage in die Übersetzung einfügen.</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Alles &amp;markieren</translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation>Den gesamten Übersetzungstext auswählen.</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Suchen ...</translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation>In der Übersetzungsdatei nach Text suchen.</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>&amp;Weitersuchen</translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation>Die Suche fortsetzen.</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation>&amp;Vorheriger Unerledigter</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation>A&amp;lle schließen</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation>&amp;Nächster Unerledigter</translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation>V&amp;orheriger</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation>Nä&amp;chster</translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation>&amp;Fertig und Nächster</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation>Kopiert den Ursprungstext in das Übersetzungsfeld.</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation>&amp;Kurzbefehle</translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation>&amp;Punktierung am Ende</translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation>&amp;Wörterbuch</translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation>Platz&amp;halter</translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation>&amp;Neues Wörterbuch ...</translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation>Ein neues Wörterbuch erzeugen.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation>&amp;Wörterbuch öffnen ...</translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation>Ein Wörterbuch zur Unterstützung bei der Übersetzung öffnen.</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation>&amp;Sortierung zurücksetzen</translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>Die Einträge in der gleichen Reihenfolge wie in der ursprünglichen Übersetzungsdatei sortieren.</translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation>&amp;Vorschläge anzeigen</translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation>Darstellung von Übersetzungsvorschlägen ein- oder ausschalten.</translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation>S&amp;tatistik</translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation>Zeige Übersetzungsstatistik an.</translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation>&amp;Handbuch</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation>Über Qt Linguist</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation>&amp;Direkthilfe</translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation>Direkthilfe</translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation>Direkthilfe-Modus aktivieren.</translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation>Suchen und &amp;übersetzen ...</translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>Die Übersetzung aller Einträge ersetzen, die dem Suchtext entsprechen.</translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation>&amp;Automatische Übersetzung ...</translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>Alle Einträge automatisch mithilfe des Wörterbuchs übersetzen.</translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation>Freigeben unter ...</translation>
    </message>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Ursprungstext</translation>
    </message>
    <message>
        <source>Context</source>
        <translation>Kontext</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>Einträge</translation>
    </message>
    <message>
        <source>Context/Label</source>
        <translation>Kontext/Label</translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation>Dieser Bereich zeigt die Kontexte an.</translation>
    </message>
    <message>
        <source>This panel lists the source labels.</source>
        <translation>Dieser Bereich zeigt die Labels der Quelldatei an.</translation>
    </message>
    <message>
        <source>Strings</source>
        <translation>Zeichenketten</translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation>Wörterbuch und Vorschläge</translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation>Quelldateien und Formulare</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Hinweise</translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation>Geändert</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Lade ...</translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation>Laden - Qt Linguist</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation>Die Datei &apos;%1&apos; scheint nicht zu den bereits geöffneten Dateien &apos;%2&apos; zu passen.

Sollen die bereits geöffneten Dateien vorher geschlossen werden?</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation>Die Datei &apos;%1&apos; scheint nicht zu der Datei &apos;%2&apos; zu passen, die ebenfalls geladen wird.

Soll die erstgenannte Datei übersprungen werden?</translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation>
            <numerusform>Eine Übersetzungseinheit geladen.</numerusform>
            <numerusform>%n Übersetzungseinheiten geladen.</numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation>Verwandte Dateien (%1);;</translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation>Übersetzungsdateien öffnen</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>Datei gespeichert.</translation>
    </message>
    <message>
        <source>Please select a file to be saved.</source>
        <translation>Bitte wählen Sie eine Datei zum Speichern.</translation>
    </message>
    <message>
        <source>This function is not available on WebAssembly</source>
        <translation>Diese Funktion ist für WebAssembly nicht verfügbar</translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>Qt-Nachrichtendateien (*.qm)
Alle Dateien (*)</translation>
    </message>
    <message>
        <source>Label: %1</source>
        <translation>Label: %1</translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation>Übersetzen - Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation>
            <numerusform>Ein Eintrag übersetzt</numerusform>
            <numerusform>%n Einträge übersetzt</numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation>Keine weiteren Vorkommen von &apos;%1&apos;. Neu anfangen?</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Qt-Wörterbücher (*.qph)
Alle Dateien (*)</translation>
    </message>
    <message>
        <source>Release</source>
        <translation>Freigeben</translation>
    </message>
    <message>
        <source>File created.</source>
        <translation>Datei erzeugt.</translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation>Drucke ...</translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation>Kontext: %1</translation>
    </message>
    <message>
        <source>finished</source>
        <translation>erledigt</translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation>ungelöst</translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation>veraltet</translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation>Drucke ... (Seite %1)</translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation>Drucken beendet</translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation>Drucken abgebrochen</translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation>Suche beginnt von oben.</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>Kann Zeichenkette &apos;%1&apos; nicht finden.</translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation>Suchen und übersetzen in &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation>Erzeugen eines neuen Wörterbuchs</translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation>Wörterbuch erzeugt.</translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation>Wörterbuch öffnen</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation>Qt-Wörterbücher (*.qph);;Alle Dateien (*)</translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>Ein Wörterbucheintrag geladen.</numerusform>
            <numerusform>%n Wörterbucheinträge geladen.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation>Hinzufügen zum Wörterbuch</translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation>Es kann kein geeignetes Wörterbuch gefunden werden.</translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation>Eintrag zu Wörterbuch %1 hinzufügen</translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation>Zu welchem Wörterbuch soll der Eintrag hinzugefügt werden?</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Qt Linguist is a tool for adding translations to Qt applications.</source>
        <translation>Qt Linguist ist ein Werkzeug zum Hinzufügen von Übersetzungen zu Qt-Anwendungen</translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation>Möchten Sie die geänderten Dateien speichern?</translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>Möchten Sie &apos;%1&apos; speichern?</translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation>Qt Linguist[*]</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation>Es wurden alle Übersetzungseinheiten abgearbeitet.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Displays the manual for %1.</source>
        <translation>Zeigt das Handbuch zu %1 an.</translation>
    </message>
    <message>
        <source>Displays information about %1.</source>
        <translation>Zeigt Informationen über %1 an.</translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation>&apos;%1&apos; &amp;speichern</translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation>&apos;%1&apos; speichern &amp;unter ...</translation>
    </message>
    <message>
        <source>&amp;Download &apos;%1&apos;</source>
        <translation>&apos;%1&apos; Herunterla&amp;den</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation>&apos;%1&apos; freigeben</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation>&apos;%1&apos; freigeben unter ...</translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation>&apos;%1&apos; &amp;schließen</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>Herunterla&amp;den</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Alles speichern</translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation>Alles f&amp;reigeben</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alle schließen</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation>Einstellungen der Übersetzungs&amp;datei für &apos;%1&apos; ...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation>&amp;Automatische Übersetzung von &apos;%1&apos; ...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation>Suchen und &amp;übersetzen in &apos;%1&apos; ...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation>Suchen und &amp;übersetzen ...</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Übersetzung</translation>
    </message>
    <message>
        <source>Validation</source>
        <translation>Validierung</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>Wörterbuch &apos;%1&apos; kann nicht gelesen werden.</translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation>Dieses Wörterbuch schließen.</translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation>Erlaubt das Hinzufügen, Ändern und Entfernen von Wörterbuch-Einträgen.</translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation>Die Einträge des Wörterbuchs drucken.</translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>Wörterbuch &apos;%1&apos; kann nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation>Möchten Sie das Wörterbuch &apos;%1&apos; speichern?</translation>
    </message>
    <message numerus="yes">
        <source>%n unfinished message(s) left.</source>
        <translation>
            <numerusform>Es ist noch eine unerledigte Nachricht vorhanden.</numerusform>
            <numerusform>Es sind noch %n unerledigte Nachrichten vorhanden.</numerusform>
        </translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>&amp;Vorschau öffnen/aktualisieren</translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation>Vorschau für Eingabemasken</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation>E&amp;instellungen ...</translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation>Zum Wörterbuch &amp;hinzufügen</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation>Vorheriger unerledigter Eintrag</translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation>Nächster unerledigter Eintrag</translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation>Zum vorigen Eintrag gehen</translation>
    </message>
    <message>
        <source>Next item</source>
        <translation>Nächster Eintrag</translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation>Eintrag als erledigt markieren und zum nächsten unerledigten Eintrag gehen</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation>Kopiert den Ursprungstext in das Übersetzungsfeld</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation>Eine Qt-Nachrichtendatei aus der aktuellen Übersetzungsdatei erzeugen. Der Dateiname wird automatisch aus dem Namen der TS-Datei abgeleitet.</translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation>Längenvarianten</translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation>Information über das Qt-Toolkit von Digia anzeigen.</translation>
    </message>
    <message>
        <source>Visualize whitespace</source>
        <translation>Leerzeichen darstellen</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Vergrößerung</translation>
    </message>
    <message>
        <source>Increase</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Decrease</source>
        <translation>Verkleinern</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Standardgröße</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Toggles the validity check of accelerators</source>
        <translation>Prüfung der Tastenkürzel ein- oder ausschalten</translation>
    </message>
    <message>
        <source>Toggles the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation>Die Prüfung der Tastenkürzel, das heißt die Übereinstimmung der kaufmännischen Und-Zeichen in Quelle und Übersetzung, ein- oder ausschalten. Bei Fehlern wird eine Warnung im Hinweisfenster angezeigt.</translation>
    </message>
    <message>
        <source>Surrounding &amp;Whitespace</source>
        <translation>Umgebende &amp;Leerzeichen</translation>
    </message>
    <message>
        <source>Toggles the validity check of surrounding whitespace.</source>
        <translation>Schaltet die Prüfung der Übereinstimmung umgebender Leerzeichen um.</translation>
    </message>
    <message>
        <source>Toggles the validity check of surrounding whitespace. If the check fails, a message is shown in the warnings window.</source>
        <translation>Schaltet die Prüfung der Übereinstimmung umgebender Leerzeichen um. Wenn die Prüfung fehlschlägt, wird eine Meldung im Warnungsfenster angezeigt.</translation>
    </message>
    <message>
        <source>Toggles the validity check of ending punctuation</source>
        <translation>Prüfung der Satzendezeichen am Ende des Textes ein- oder ausschalten</translation>
    </message>
    <message>
        <source>Toggles the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation>Die Prüfung der Satzendezeichen am Ende des Textes ein- oder ausschalten. Bei Fehlern wird eine Warnung im Hinweisfenster angezeigt.</translation>
    </message>
    <message>
        <source>Toggles checking that phrase suggestions are used</source>
        <translation>Überprüfung, ob Wörterbucheinträge benutzt werden, ein- oder ausschalten</translation>
    </message>
    <message>
        <source>Toggles checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation>Die Prüfung der Verwendung der Wörterbuchvorschläge ein- oder ausschalten. Bei Fehlern wird eine Warnung im Hinweisfenster angezeigt.</translation>
    </message>
    <message>
        <source>Toggles the validity check of place markers</source>
        <translation>Prüfung der Platzhalter ein- oder ausschalten</translation>
    </message>
    <message>
        <source>Toggles the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation>Die Prüfung der Platzhalter, das heißt, ob %1, %2 usw. in Ursprungstext und Übersetzung übereinstimmend verwendet werden, ein- oder ausschalten. Bei Fehlern wird eine Warnung im Hinweisfenster angezeigt.</translation>
    </message>
    <message>
        <source>Toggles visualize whitespace in editors</source>
        <translation>Schaltet die Darstellung der Leerzeichen in den Editoren um</translation>
    </message>
    <message>
        <source>Guesses</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Show more</source>
        <translation>Mehr anzeigen</translation>
    </message>
    <message>
        <source>Alt++</source>
        <translation>Alt++</translation>
    </message>
    <message>
        <source>Show fewer</source>
        <translation>Weniger anzeigen</translation>
    </message>
    <message>
        <source>Alt+-</source>
        <translation>Alt+-</translation>
    </message>
    <message>
        <source>Alt+0</source>
        <translation>Alt+0</translation>
    </message>
    <message>
        <source>D&amp;one</source>
        <translation>&amp;Fertig</translation>
    </message>
    <message>
        <source>Mark item as done</source>
        <translation>Eintrag als erledigt markieren</translation>
    </message>
    <message>
        <source>Mark this item as done.</source>
        <translation>Diesen Eintrag als erledigt markieren.</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>&amp;Rückwärts suchen</translation>
    </message>
    <message>
        <source>Shift+F3</source>
        <translation>Shift+F3</translation>
    </message>
    <message>
        <source>&amp;QML preview</source>
        <translation>&amp;QML-Vorschau</translation>
    </message>
    <message>
        <source>Displays a preview of QML documents.</source>
        <translation>Zeigt eine Vorschau von QML-Dokumenten.</translation>
    </message>
    <message>
        <source>AI Translation...</source>
        <translation>KI-Übersetzung...</translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>Dieser Bereich erlaubt die Darstellung und Änderung der Übersetzung eines Textes.</translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Ursprungstext</translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation>Dieser Bereich zeigt den Ursprungstext.</translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation>Ursprungstext (Plural)</translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation>Dieser Bereich zeigt die Pluralform des Ursprungstexts.</translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation>Hinweise des Entwicklers</translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation>Dieser Bereich zeigt eventuelle Kommentare und den Kontext, in dem der Text auftritt.</translation>
    </message>
    <message>
        <source>NCR mode</source>
        <translation>NCR-Modus</translation>
    </message>
    <message>
        <source>Toggles Numeric Character Reference Mode for displaying the source text and the translations.</source>
        <translation>Schaltet den Modus für numerische Zeichen zur Anzeige von Quelltext und Übersetzung um.</translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation>Hier können Sie Hinweise für den eigenen Gebrauch eintragen. Diese haben keinen Einflusse auf die Übersetzung.</translation>
    </message>
    <message>
        <source>Translation to %1 (%2)</source>
        <translation>Übersetzung in %1 (%2)</translation>
    </message>
    <message>
        <source>Translation to %1</source>
        <translation>Übersetzung in %1</translation>
    </message>
    <message>
        <source>Translator comments for %1</source>
        <translation>Hinweise des Übersetzers zu %1</translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation>Hier können Sie die Übersetzung des Ursprungstextes eingeben bzw. ändern.</translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation>&apos;%1&apos;
Zeile: %2</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation>Bearbeitungsstand von %1</translation>
    </message>
    <message>
        <source>&lt;unnamed label&gt;</source>
        <translation>&lt;unbenannt&gt;</translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation>&lt;Kontexthinweis&gt;</translation>
    </message>
    <message numerus="yes">
        <source>%n unfinished message(s) left.</source>
        <translation>
            <numerusform>Es ist noch eine unerledigte Nachricht vorhanden.</numerusform>
            <numerusform>Es sind noch %n unerledigte Nachrichten vorhanden.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation>Parse-Fehler bei Zeile %1, Spalte %2 (%3).</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
    <message>
        <source>(New Entry)</source>
        <translation>(Neuer Eintrag)</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>Wörterbuch &apos;%1&apos; kann nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>Edit Phrase Book</source>
        <translation>Wörterbuch bearbeiten</translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation>Dieses Fenster erlaubt das Hinzufügen, Ändern und Entfernen von Wörterbuch-Einträgen.</translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation>&amp;Übersetzung:</translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>Dies ist der Text, der in der Zielsprache dem Ursprungstext entspricht.</translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation>&amp;Ursprungstext:</translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation>Dies ist die Definition des Ursprungstextes.</translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation>Dies ist der Text der Ursprungssprache.</translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation>&amp;Definition:</translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>Einen neuen Eintrag ins Wörterbuch einfügen.</translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation>&amp;Neuer Eintrag</translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation>Den Eintrag aus dem Wörterbuch entfernen.</translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation>&amp;Eintrag entfernen</translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation>&amp;Einstellungen ...</translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation>Änderungen speichern.</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicken Sie hier, um das Fenster zu schließen.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Source phrase</source>
        <translation>Ursprungstext</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Übersetzung</translation>
    </message>
    <message>
        <source>Definition</source>
        <translation>Definition</translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Go to</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <source>Guess from &apos;%1&apos; (%2)</source>
        <translation>Vorschlag &apos;%1&apos; (%2)</translation>
    </message>
    <message>
        <source>Guess from &apos;%1&apos;</source>
        <translation>Vorschlag &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Translation files (%1);;</source>
        <translation>Übersetzungsdateien (%1);;</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Quelltext nicht verfügbar&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Datei %1 nicht vorhanden&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation>&lt;i&gt;Datei %1 nicht lesbar&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>Statistics</source>
        <translation>Statistiken</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Übersetzung</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Wörter:</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Zeichen:</translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation>Zeichen (mit Leerzeichen):</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Unfinished</source>
        <translation>Unerledigt</translation>
    </message>
    <message>
        <source>Total translatable messages:</source>
        <translation>Gesamtzahl übersetzbarer Einträge:</translation>
    </message>
    <message>
        <source>Total finished:</source>
        <translation>Gesamtzahl der erledigten Einträge:</translation>
    </message>
    <message>
        <source>Without warnings:</source>
        <translation>Ohne Warnungen:</translation>
    </message>
    <message>
        <source>With warnings:</source>
        <translation>Mit Warnungen:</translation>
    </message>
    <message>
        <source>Unfinished:</source>
        <translation>Unerledigt:</translation>
    </message>
    <message>
        <source>Total messages including obsolete:</source>
        <translation>Gesamtzahl einschließlich als &apos;obsolet&apos; gekennzeichneter Einträge:</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Dieses Fenster erlaubt die Suche in der Übersetzungsdatei.</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Geben Sie den Text ein, nach dem gesucht werden soll.</translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation>&amp;Ursprungstext:</translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation>&amp;Übersetzung:</translation>
    </message>
    <message>
        <source>Search options</source>
        <translation>Sucheinstellungen</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Wenn aktiviert, werden Texte wie &apos;TeX&apos; und &apos;tex&apos; als unterschiedlich betrachtet.</translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation>&amp;Groß-/Kleinschreibung beachten</translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation>Neue Übersetzung als &amp;erledigt markieren</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Klicken Sie hier, um zum nächsten Vorkommen des Suchtextes zu springen.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Weitersuchen</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation>Alle übersetzen</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Klicken Sie hier, um das Fenster zu schließen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>%1 (%2)</source>
        <extracomment>&lt;english&gt; (&lt;endonym&gt;) (language names)</extracomment>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Any Territory</source>
        <translation>Beliebiges Territorium</translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation>Einstellungen für &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Source language</source>
        <translation>Ursprungssprache</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Land/Region</translation>
    </message>
    <message>
        <source>Target language</source>
        <translation>Zielsprache</translation>
    </message>
</context>
<context>
    <name>MachineTranslationDialog</name>
    <message>
        <source>Context</source>
        <translation>Kontext</translation>
    </message>
    <message>
        <source>Model</source>
        <translation>Modell</translation>
    </message>
    <message>
        <source>All Items</source>
        <translation>Alle Einträge</translation>
    </message>
    <message>
        <source>Text Based</source>
        <translation>Text-basiert</translation>
    </message>
    <message>
        <source>ID Based</source>
        <translation>ID-basiert</translation>
    </message>
    <message>
        <source>No messages selected</source>
        <translation>Keine Nachrichten ausgewählt</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Gruppen</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Translation status: -</source>
        <extracomment>Default display when no translations have been processed yet</extracomment>
        <translation>Übersetzungsstatus: -</translation>
    </message>
    <message>
        <source>Apply Translations</source>
        <translation>Übersetzungen übernehmen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Translation Log</source>
        <translation>Logmeldungen der Übersetzung</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Konfiguration</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation>Auswahl</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Translation status: %1/%2 source texts translated, %3/%2 failed.</source>
        <translation>Übersetzungsstatus: %1/%2 Nachrichten übersetzt, %3/%2 fehlgeschlagen.</translation>
    </message>
    <message>
        <source>&lt;hr/&gt;&lt;b&gt;Translation completed: %1/%2 translated, %3/%2 failed.&lt;/b&gt;</source>
        <translation>&lt;hr/&gt;&lt;b&gt;Übersetzung abgeschlossen: %1/%2 übersetzt, %3/%2 fehlgeschlagen.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>%n translated item(s) will be discarded. Continue?</source>
        <translation>
            <numerusform>Eine übersetzte Nachricht wird verworfen. Fortsetzen?</numerusform>
            <numerusform>%n übersetzte Nachrichten werden verworfen. Fortsetzen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Translation Stopped.</source>
        <translation>Übersetzung angehalten.</translation>
    </message>
    <message>
        <source>Please verify the service URL is valid and a translation model is selected.</source>
        <translation>Bitte überprüfen Sie, dass die URL des Dienstes gültig ist und ein Übersetzungsmodell ausgewählt ist.</translation>
    </message>
    <message>
        <source>Please select a file for translation.</source>
        <translation>Bitte wählen Sie eine Datei zur Übersetzung aus.</translation>
    </message>
    <message>
        <source>Please select at least one context/label to translate.</source>
        <translation>Bitte wählen Sie mindestens einen Kontext oder ein Label zur Übersetzung aus.</translation>
    </message>
    <message>
        <source>No items to translate. All selected messages already have translations.</source>
        <translation>Es gibt keine Texte zu übersetzen. Alle ausgewählten Texte haben bereits Übersetzungen.</translation>
    </message>
    <message>
        <source>Translation Started</source>
        <translation>Übersetzung gestartet</translation>
    </message>
    <message>
        <source>Plural count expected %1, got %2 for &quot;%3&quot;.</source>
        <translation>Für &quot;%3&quot; werden %1 Pluralformen erwartet; es wurden jedoch %2 erhalten.</translation>
    </message>
    <message>
        <source>Translation Batch:</source>
        <translation>Übersetzungsstapel:</translation>
    </message>
    <message>
        <source>Translations Applied.</source>
        <translation>Übersetzungen angewandt.</translation>
    </message>
    <message>
        <source>Failed Translation(s):</source>
        <translation>Fehlgeschlagenene Übersetzung(en):</translation>
    </message>
    <message>
        <source>Selection status: -</source>
        <extracomment>No selected items</extracomment>
        <translation>Auswahl: -</translation>
    </message>
    <message numerus="yes">
        <source>Selected %n item(s).</source>
        <translation>
            <numerusform>1 Übersetzung ausgewählt.</numerusform>
            <numerusform>%n Übersetzungen ausgewählt.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Selected %n item(s) in %1 group(s).</source>
        <translation>
            <numerusform>1 Übersetzung in %1 Gruppe(n) ausgewählt.</numerusform>
            <numerusform>%n Übersetzungen in %1 Gruppe(n) ausgewählt.</numerusform>
        </translation>
    </message>
    <message>
        <source>Not connected - click &quot;Connect&quot; to fetch models</source>
        <translation>Nicht verbunden - Klicken Sie auf &quot;Verbinden&quot;, um die verfügbaren Modelle zu bestimmen</translation>
    </message>
    <message>
        <source>Connection failed - verify server URL and click &quot;Connect&quot;</source>
        <translation>Verbindung schlug fehl - Prüfen Sie die Server-URL und klicken Sie auf &quot;Verbinden&quot;</translation>
    </message>
    <message>
        <source>URL modified - click &quot;Connect&quot; to apply</source>
        <translation>URL modifiziert - klicken Sie noch einmal auf &quot;Verbinden&quot;</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <source>Warning: Maximum JSON Format Tries: Low value may cause unnecessary format switching due to temporary errors. Recommended: 3 or higher.</source>
        <extracomment>&quot;Maximum JSON Format Tries&quot; should use the same translation as the label &quot;Maximum JSON Format Tries&quot; in Advanced Settings</extracomment>
        <translation>Warnung: Maximalzahl der JSON-Format-Versuche: Niedrige Werte können unnötige Formatwechsel bei vorübergehenden Fehlern bewirken. Empfohlen sind 3 oder mehr.</translation>
    </message>
    <message>
        <source>Warning: Maximum Retries: Should be at least 3x &apos;Maximum JSON Format Tries&apos; for full fallback coverage</source>
        <extracomment>&quot;Maximum Retries&quot; and &quot;Maximum JSON Format Tries&quot; should use the same translations as the labels &quot;Maximum Retries&quot; and &quot;Maximum JSON Format Tries&quot; in Advanced Settings</extracomment>
        <translation>Warnung: Maximalzahl der Versuchswiederholungen: Es sollte mindestens der dreifache Wert der &quot; Maximalzahl der JSON-Format-Versuche&quot; für eine vollständige Fallback-Abdeckung verwendet werden</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Verbinde...</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Auto Translation</source>
        <translation>Automatische Übersetzung</translation>
    </message>
    <message>
        <source>API Type</source>
        <translation>API-Typ</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Server URL</source>
        <translation>Server-URL</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>API Key</source>
        <translation>API-Schlüssel</translation>
    </message>
    <message>
        <source>Optional: Required only for cloud APIs (OpenAI, Anthropic, etc.)</source>
        <translation>Optional: Nur für Cloud-APIs (OpenAI, Anthropic, etc.)</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Log Raw Requests</source>
        <translation>Anfragen in Rohform loggen</translation>
    </message>
    <message>
        <source>Maximum number of retry attempts for failed translation requests</source>
        <translation>Maximalzahl der Versuchswiederholungen für fehlgeschlagene Übersetzungsanforderungen</translation>
    </message>
    <message>
        <source>Maximum number of translation batches to process in parallel</source>
        <translation>Maximalzahl der Übersetzungsstapel zur parallelen Verarbeitung</translation>
    </message>
    <message>
        <source>Timeout for network requests in seconds</source>
        <translation>Timeout für Netzwerkanforderungen in Sekunden</translation>
    </message>
    <message>
        <source>Transfer Timeout (seconds)</source>
        <translation>Timeout für Übertragung (Sekunden)</translation>
    </message>
    <message>
        <source>Maximum number of source texts to include in each translation batch</source>
        <translation>Maximalzahl der Texte pro Übersetzungsstapel</translation>
    </message>
    <message>
        <source>LLM temperature (lower = more deterministic, higher = more creative)</source>
        <translation>LLM-Temperatur (niedriger = deterministischer, höher = kreativer)</translation>
    </message>
    <message>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <source>Timeout for waking up an idle Ollama server in seconds</source>
        <translation>Timeout zum Aufwecken eines freien Ollama-Servers in Sekunden</translation>
    </message>
    <message>
        <source>Ollama Wake-up Timeout (seconds)</source>
        <translation>Ollama-Server-Timeout zum Aufwecken (Sekunden)</translation>
    </message>
    <message>
        <source>color: #b58900;</source>
        <translation>color: #b58900;</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Reset to Defaults</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Maximum Retries</source>
        <translation>Maximalzahl der Versuchswiederholungen</translation>
    </message>
    <message>
        <source>Maximum Concurrent Batches</source>
        <translation>Maximalzahl der gleichzeitigen Stapel</translation>
    </message>
    <message>
        <source>Maximum Batch Size</source>
        <translation>Maximale Stapelgröße</translation>
    </message>
    <message>
        <source>Number of attempts of sending JSON-format requests before falling back to non-JSON format requests</source>
        <translation>Anzahl der Versuche mit Anforderungen im JSON-Format vor Fallback auf Anforderungen in andereren Formaten</translation>
    </message>
    <message>
        <source>Maximum JSON Format Tries</source>
        <translation>Maximalzahl der JSON-Format-Versuche</translation>
    </message>
    <message>
        <source>Optional: Provide additional context about your application (e.g., medical software, game, financial app) for more accurate translations.</source>
        <translation>Optional: Geben Sie zusätzlichen Kontext für Ihre Anwendung an (z.B. Medizinische Software, Spiel, finanztechnische Anwendung), um genauere Übersetzungen zu erhalten.</translation>
    </message>
</context>
</TS>
